from django.core.management.base import BaseCommand
from django.contrib.auth.models import Permission

class Command(BaseCommand):
    help = 'List all permission names, slugs, and apps'

    def handle(self, *args, **kwargs):
        permissions = Permission.objects.all()
        self.stdout.write("Permission Name\tPermission Slug")
        for permission in permissions:
            self.stdout.write(f"{permission.name}\t{permission.content_type.app_label}.{permission.codename}")



from django.contrib.admin.widgets import AutocompleteSelect
from django.conf import settings
from django import forms
import json


class ChainedAdminSelect(AutocompleteSelect):
    def build_attrs(self, base_attrs, extra_attrs=None):
        """
        Set select2's AJAX attributes.

        Attributes can be set using the html5 data attribute.
        Nested attributes require a double dash as per
        https://select2.org/configuration/data-attributes#nested-subkey-options
        """
        attrs = super().build_attrs(base_attrs, extra_attrs=extra_attrs)
        attrs.setdefault("class", "")
        attrs.update(
            {
                "data-ajax--cache": "true",
                "data-ajax--delay": 250,
                "data-ajax--type": "GET",
                "data-ajax--url": self.get_url(),
                "data-app-label": self.field.model._meta.app_label,
                "data-model-name": self.field.model._meta.model_name,
                "data-field-name": self.field.name,
                "data-theme": "admin-autocomplete",
                "data-allow-clear": json.dumps(not self.is_required),
                "data-placeholder": "",  # Allows clearing of the input.
                "data-dynamic-filters": json.dumps(self.field.dynamic_filters),
                "data-automatically-select-unique-choice": json.dumps(self.field.automatically_select_unique_choice),
                "data-filters": json.dumps(self.field.filters),
                "lang": self.i18n_name,
                "class": (attrs["class"]
                         + (" " if attrs["class"] else "")).replace("admin-autocomplete", "admin-autocomplete-chained"),
            }
        )
        return attrs

    @property
    def media(self):
        extra = "" if settings.DEBUG else ".min"
        i18n_file = (
            ("admin/js/vendor/select2/i18n/%s.js" % self.i18n_name,)
            if self.i18n_name
            else ()
        )
        return forms.Media(
            js=(
                   "admin/js/vendor/jquery/jquery%s.js" % extra,
                   "admin/js/vendor/select2/select2.full%s.js" % extra,
               )
               + i18n_file
               + (
                   "admin/js/jquery.init.js",
                   "js/autocomplete.chained.js",
               ),
            css={
                "screen": (
                    "admin/css/vendor/select2/select2%s.css" % extra,
                    "admin/css/autocomplete.css",
                ),
            },
        )


from setuptools import setup, find_packages
from pathlib import Path
this_directory = Path(__file__).parent

long_description = (this_directory / "README.md").read_text()

setup(
    name="django_superapp",
    packages=find_packages(where="src"),
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/django-superapp/django-superapp",
    author="Django SuperApp",
    author_email="django-superapp@bringes.io",
    license="MIT",
    package_dir={"": "src"},
    install_requires=[
        "Django >= 5.0.0",
        "django-unfold >= 0.22.0",
        "django-svelte-jsoneditor >= 0.4.2",
        "django-import-export >= 4.0.3",
        "django-admin-confirm >= 1.0.0",
    ],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Framework :: Django",
        "Framework :: Django :: 5.0",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Application",
        "Operating System :: OS Independent",
        "Natural Language :: English",
    ],
    python_requires=">=3.8",
    project_urls={
        "Bug Reports": "https://github.com/django-superapp/django-superapp/issues",
        "Source": "https://github.com/django-superapp/django-superapp",
    },
)
